==> driza-0.5.tar.gz: driza-0.5.0/Driza/dialogs/dsplash.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#textBrowser1: La ventana con las opciones
#pixmapLabel1: La fotografia


from Driza.ui.dialogos.uidsplash import DialogoSplash
from qt import *


class DSplash(DialogoSplash):
	"""Dialogo que muestra un acceso rápido a las acciones que puede realizar el usuario"""

	def __init__(self,parent=None,name=None,modal=0,fl=0):
		DialogoSplash.__init__(self,parent,name,modal,fl)
		#VARIABLES PRIVADAS
		self.__textohtml=""

		self.pixmapLabel1.setPixmap(QPixmap(self.parent().parent.rutaimagenes()+"driza.png"))
		self.__conexiones()
		self.__inithtml()
		self.textBrowser1.append(self.__textohtml)
	
	#FUNCIONES PRIVADAS

	def __conexiones(self):
		"""Bloque de conexiones"""
		self.connect(self.textBrowser1,SIGNAL("linkClicked(const QString & )"),self.__enlace)

	def __inithtml(self):
		"""Devuelve el html que muestra la ventana"""
		self.__textohtml="<table> \\ <tr><td><a href=\"nuevo\">Nuevo Archivo</a></td></tr> <tr> <td><a href=\"abrir\">Abrir fichero</a></td></tr> "
		for i in range(5):
			try: 
				nfichero=self.parent().parent.config["lfichero"][i]
				ristra="<tr><td><a href=\"%d\">%s</a></td></tr>" % (i,nfichero)
				self.__textohtml+=ristra
			except:
				i=4
		self.__textohtml+="<tr><td><a href=\"salida\">Dialogo de salida</a></td></tr></table>"

	def __enlace(self,parametro):
		"""Define las acciones que realizará el programa tras pulsar en un enlace"""
		if parametro=="nuevo":
			self.textBrowser1.setSource("")
		elif parametro=="abrir":
			self.textBrowser1.setSource("")
			self.parent().abrirfichero()
		elif parametro=="0":
			self.textBrowser1.setSource("")
			self.parent().parent.cargarfichero(self.parent().parent.config["lfichero"][0])
		elif parametro=="salida":
			self.textBrowser1.setSource("")
			self.parent().hide()
			self.parent().parent.vsalida.show()
		else:
			self.reject()
			return
		self.accept()

==> driza-0.5.2.tar.gz: driza-0.5.2/Driza/dialogs/dsplash.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#textBrowser1: La ventana con las opciones
#pixmapLabel1: La fotografia


from Driza.ui.dialogos.uidsplash import DialogoSplash
from qt import *


class DSplash(DialogoSplash):
	"""Dialogo que muestra un acceso rápido a las acciones que puede realizar el usuario"""
	def __init__(self,parent,gestortemas):
		DialogoSplash.__init__(self,parent,"Dialogo Splash")
		#VARIABLES PRIVADAS
		self.__textohtml=""
		self.__gestortemas=gestortemas

		self.pixmapLabel1.setPixmap(self.__gestortemas.portada())
		self.__conexiones()
		self.__inithtml()
		self.textBrowser1.append(self.__textohtml)
	
	#FUNCIONES PRIVADAS

	def __conexiones(self):
		"""Bloque de conexiones"""
		self.connect(self.textBrowser1,SIGNAL("linkClicked(const QString & )"),self.__enlace)

	def __inithtml(self):
		"""Devuelve el html que muestra la ventana"""
		self.__textohtml="<table> \\ <tr><td><a href=\"nuevo\">Nuevo Archivo</a></td></tr> <tr> <td><a href=\"abrir\">Abrir fichero</a></td></tr> "
		for i in range(5):
			try: 
				nfichero=self.parent().parent.config["lfichero"][i]
				ristra="<tr><td><a href=\"%d\">%s</a></td></tr>" % (i,nfichero)
				self.__textohtml+=ristra
			except:
				i=4
		self.__textohtml+="<tr><td><a href=\"salida\">Dialogo de salida</a></td></tr></table>"

	def __enlace(self,parametro):
		"""Define las acciones que realizará el programa tras pulsar en un enlace"""
		if parametro=="nuevo":
			self.textBrowser1.setSource("")
		elif parametro=="abrir":
			self.textBrowser1.setSource("")
			self.parent().abrirfichero()
		elif parametro=="0":
			self.textBrowser1.setSource("")
			self.parent().parent.cargarfichero(self.parent().parent.config["lfichero"][0])
		elif parametro=="salida":
			self.textBrowser1.setSource("")
			self.parent().hide()
			self.parent().parent.vsalida.show()
		else:
			self.reject()
			return
		self.accept()
